@@ -8,13 +8,13 @@ class DashboardESDocument(ElasticsearchDocument):
     Schema for the ES dashboard ES document
     """
     def __init__(self,
-                 dashboard_group,  # type: str
-                 dashboard_name,  # type: str
+                 group_name,  # type: str
+                 name,  # type: str
                  description,  # type: Union[str, None]
                  total_usage,  # type: int
                  product='',  # type: Optional[str]
                  cluster='',  # type: Optional[str]
-                 dashboard_group_description=None,  # type: Optional[str]
+                 group_description=None,  # type: Optional[str]
                  query_names=None,  # type:  Union[List[str], None]
                  group_url=None,  # type: Optional[str]
                  url=None,  # type: Optional[str]
@@ -23,8 +23,8 @@ class DashboardESDocument(ElasticsearchDocument):
                  tags=None  # type: list
                  ):
         # type: (...) -> None
-        self.dashboard_group = dashboard_group
-        self.dashboard_name = dashboard_name
+        self.group_name = group_name
+        self.name = name
         self.description = description
         self.cluster = cluster
         self.product = product
@@ -33,6 +33,6 @@ class DashboardESDocument(ElasticsearchDocument):
         self.uri = uri
         self.last_successful_run_timestamp = last_successful_run_timestamp
         self.total_usage = total_usage
-        self.dashboard_group_description = dashboard_group_description
+        self.group_description = group_description
         self.query_names = query_names
         self.tags = tags
