@@ -5,17 +5,18 @@ from databuilder.models.neo4j_csv_serde import Neo4jCsvSerializable, NODE_KEY, \
     RELATION_END_LABEL, RELATION_TYPE, RELATION_REVERSE_TYPE
 
 from databuilder.models.table_metadata import TableMetadata
+from databuilder.models.timestamp import timestamp_constants
 
 
 class TableLastUpdated(Neo4jCsvSerializable):
     # constants
-    LAST_UPDATED_NODE_LABEL = 'Timestamp'
+    LAST_UPDATED_NODE_LABEL = timestamp_constants.NODE_LABEL
     LAST_UPDATED_KEY_FORMAT = '{db}://{cluster}.{schema}/{tbl}/timestamp'
-    TIMESTAMP_PROPERTY = 'last_updated_timestamp'
-    TIMESTAMP_NAME_PROPERTY = 'name'
+    TIMESTAMP_PROPERTY = timestamp_constants.DEPRECATED_TIMESTAMP_PROPERTY
+    TIMESTAMP_NAME_PROPERTY = timestamp_constants.TIMESTAMP_NAME_PROPERTY
 
-    TABLE_LASTUPDATED_RELATION_TYPE = 'LAST_UPDATED_AT'
-    LASTUPDATED_TABLE_RELATION_TYPE = 'LAST_UPDATED_TIME_OF'
+    TABLE_LASTUPDATED_RELATION_TYPE = timestamp_constants.LASTUPDATED_RELATION_TYPE
+    LASTUPDATED_TABLE_RELATION_TYPE = timestamp_constants.LASTUPDATED_REVERSE_RELATION_TYPE
 
     def __init__(self,
                  table_name,  # type: str
@@ -83,7 +84,8 @@ class TableLastUpdated(Neo4jCsvSerializable):
             NODE_KEY: self.get_last_updated_model_key(),
             NODE_LABEL: TableLastUpdated.LAST_UPDATED_NODE_LABEL,
             TableLastUpdated.TIMESTAMP_PROPERTY: self.last_updated_time,
-            TableLastUpdated.TIMESTAMP_NAME_PROPERTY: TableLastUpdated.TIMESTAMP_PROPERTY
+            timestamp_constants.TIMESTAMP_PROPERTY: self.last_updated_time,
+            TableLastUpdated.TIMESTAMP_NAME_PROPERTY: timestamp_constants.TimestampName.last_updated_timestamp.name
         })
 
         return results
